@@ -230,8 +230,8 @@ def domain_host(ctx, build, vary):
         # wrap our build command
         _ = _.prepend_to_build_command(*SUDO, '-E', *(nsenter[len(SUDO):]), *make_sudo_command(*current_user_group()))
     else:
-        logger.warn("Not using sudo for domain_host; your build may fail. See man page for other options.")
-        logger.warn("Be sure to `echo 1 > /proc/sys/kernel/unprivileged_userns_clone` if on a Debian system.")
+        logger.warning("Not using sudo for domain_host; your build may fail. See man page for other options.")
+        logger.warning("Be sure to `echo 1 > /proc/sys/kernel/unprivileged_userns_clone` if on a Debian system.")
         if "user_group" in ctx.spec and ctx.spec.user_group.available:
             logger.error("Incompatible variations: domain_host.use_sudo False, user_group.available non-empty.")
             raise ValueError("Incompatible variations; check the log for details.")
@@ -425,7 +425,7 @@ def user_group(ctx, build, vary):
         return build
 
     if not ctx.spec.user_group.available:
-        logger.warn("IGNORING user_group variation; supply more usergroups "
+        logger.warning("IGNORING user_group variation; supply more usergroups "
         "with --variations=user_group.available+=USER1:GROUP1;USER2:GROUP2 or "
         "alternatively, suppress this warning with --variations=-user_group")
         return build
@@ -579,8 +579,8 @@ class Variations(collections.namedtuple('_Variations', 'spec verbosity min_cpus
 
 
 def print_sudoers(spec):
-    logger.warn("This feature is EXPERIMENTAL, use at your own risk.")
-    logger.warn("The output may be out-of-date, please file bugs if it doesn't work...")
+    logger.warning("This feature is EXPERIMENTAL, use at your own risk.")
+    logger.warning("The output may be out-of-date, please file bugs if it doesn't work...")
 
     user, group = current_user_group()
     a = "[a-zA-Z0-9]"
